==> calligra_2.9.7.orig.tar.xz: calligra-2.9.7/stage/part/animations/KPrAnimTransitionFilter.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrAnimTransitionFilter.h"
#include "KoShapeSavingContext.h"
#include "KoPASavingContext.h"

KPrAnimTransitionFilter::KPrAnimTransitionFilter(KPrShapeAnimation *shapeAnimation)
: KPrAnimationBase(shapeAnimation)
{
}

KPrAnimTransitionFilter::~KPrAnimTransitionFilter()
{
}

bool KPrAnimTransitionFilter::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
{
    KPrAnimationBase::loadOdf(element, context);
    return true;
}

bool KPrAnimTransitionFilter::saveOdf(KoPASavingContext & paContext) const
{
    Q_UNUSED(paContext);
    return true;
}

void KPrAnimTransitionFilter::init(KPrAnimationCache *animationCache, int step)
{
    Q_UNUSED(animationCache);
    Q_UNUSED(step);
}

void KPrAnimTransitionFilter::next(int currentTime)
{
    Q_UNUSED(currentTime);
}

==> calligra_25.08.2+dfsg.orig.tar.xz: calligra-25.08.2/stage/part/animations/KPrAnimTransitionFilter.cpp <==
/* This file is part of the KDE project
 * SPDX-FileCopyrightText: 2010 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrAnimTransitionFilter.h"
#include "KoPASavingContext.h"
#include "KoShapeSavingContext.h"

KPrAnimTransitionFilter::KPrAnimTransitionFilter(KPrShapeAnimation *shapeAnimation)
    : KPrAnimationBase(shapeAnimation)
{
}

KPrAnimTransitionFilter::~KPrAnimTransitionFilter() = default;

bool KPrAnimTransitionFilter::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
{
    KPrAnimationBase::loadOdf(element, context);
    return true;
}

bool KPrAnimTransitionFilter::saveOdf(KoPASavingContext &paContext) const
{
    Q_UNUSED(paContext);
    return true;
}

void KPrAnimTransitionFilter::init(KPrAnimationCache *animationCache, int step)
{
    Q_UNUSED(animationCache);
    Q_UNUSED(step);
}

void KPrAnimTransitionFilter::next(int currentTime)
{
    Q_UNUSED(currentTime);
}
